﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Xml;
using System.Collections.Specialized;

namespace ConfigurationDemo
{
    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine(GetAuthor("author"));
          //  Console.WriteLine(GetAuthor("article"));

            Console.WriteLine();

            CompanyAddress ca = (CompanyAddress)System.Configuration.ConfigurationSettings.GetConfig("CompanyAddress");
            Console.WriteLine(ca.Country);
            Console.WriteLine(ca.CompanyName);

            Console.WriteLine();

            NameValueCollection nvc = (NameValueCollection)ConfigurationSettings.GetConfig("DBSettings");

            
            foreach (string key in nvc.AllKeys)
            {
                foreach (string value in nvc.GetValues(key))
                {
                    Console.WriteLine(value);
                }
            }
            Console.ReadLine();
        }

        public static string GetAuthor(string sectionName)
        {
            return ConfigurationSettings.AppSettings[sectionName];
        }
    }

    public class MyConfigHandler : IConfigurationSectionHandler
    {
        //parent - The configuration settings in a corresponding parent configuration section.
        //configContext - An HttpConfigurationContext when Create is called from the ASP.NET configuration system. Otherwise, this parameter is reserved and is a null reference.
        //section - The XmlNode that contains the configuration information from the configuration file. Provides direct access to the XML contents of the configuration section.
        //Return value - A configuration object.
        public object Create(object parent, object configContext, XmlNode section)
        {
            CompanyAddress ca = new CompanyAddress();
            ca.CompanyName = section.SelectSingleNode("companyName").InnerText;
            ca.DoorNo = section.SelectSingleNode("doorNo").InnerText;
            ca.Street = section.SelectSingleNode("street").InnerText;
            ca.City = section.SelectSingleNode("city").InnerText;
            ca.PastalCode = section.SelectSingleNode("postalCode").InnerText;
            ca.Country = section.SelectSingleNode("country").InnerText;

            return ca;
        }

        public MyConfigHandler()
        {
        }
    }

    public class CompanyAddress
    {
        private string companyName;
        private string doorNo;
        private string street;
        private string city;
        private string pastalCode;
        private string country;

        public CompanyAddress()
        {
            companyName = doorNo = street = pastalCode = country = string.Empty;
        }

        public string CompanyName
        {
            get
            {
                return companyName;
            }
            set { companyName = value; }
        }
        public string DoorNo
        {
            get
            {
                return doorNo;
            }
            set { doorNo = value; }
        }
        public string Street
        {
            get
            {
                return street;
            }
            set { street = value; }
        }
        public string City
        {
            get
            {
                return city;
            }
            set { city = value; }
        }
        public string PastalCode
        {
            get
            {
                return pastalCode;
            }
            set { pastalCode = value; }
        }
        public string Country
        {
            get
            {
                return country;
            }
            set { country = value; }
        }
    }
}
/*


	<appSettings>
		<add key="article" value="Configuration Sections"/>
		<add key="author" value="Palanisamy Veerasingam"/>
	</appSettings>
*/